@@ -76,50 +76,50 @@ QgsMemoryProvider::QgsMemoryProvider( const QString &uri, const ProviderOptions
   mNextFeatureId = 1;
 
   setNativeTypes( QList< NativeType >()
-                  << QgsVectorDataProvider::NativeType( tr( "Whole Number (integer)" ), QStringLiteral( "integer" ), QVariant::Int, 0, 10 )
+                  << QgsVectorDataProvider::NativeType( tr( "Whole Number (integer)" ), QStringLiteral( "integer" ), QMetaType::Type::Int, 0, 10 )
                   // Decimal number from OGR/Shapefile/dbf may come with length up to 32 and
                   // precision up to length-2 = 30 (default, if width is not specified in dbf is length = 24 precision = 15)
                   // We know that double (QVariant::Double) has only 15-16 significant numbers,
                   // but setting that correct limits would disable the use of memory provider with
                   // data from Shapefiles. In any case, the data are handled as doubles.
                   // So the limits set here are not correct but enable use of data from Shapefiles.
-                  << QgsVectorDataProvider::NativeType( tr( "Decimal Number (real)" ), QStringLiteral( "double" ), QVariant::Double, 0, 32, 0, 30 )
-                  << QgsVectorDataProvider::NativeType( tr( "Text (string)" ), QStringLiteral( "string" ), QVariant::String, 0, 255 )
+                  << QgsVectorDataProvider::NativeType( tr( "Decimal Number (real)" ), QStringLiteral( "double" ), QMetaType::Type::Double, 0, 32, 0, 30 )
+                  << QgsVectorDataProvider::NativeType( tr( "Text (string)" ), QStringLiteral( "string" ), QMetaType::Type::QString, 0, 255 )
 
                   // date type
-                  << QgsVectorDataProvider::NativeType( QgsVariantUtils::typeToDisplayString( QVariant::Date ), QStringLiteral( "date" ), QVariant::Date, -1, -1, -1, -1 )
-                  << QgsVectorDataProvider::NativeType( QgsVariantUtils::typeToDisplayString( QVariant::Time ), QStringLiteral( "time" ), QVariant::Time, -1, -1, -1, -1 )
-                  << QgsVectorDataProvider::NativeType( QgsVariantUtils::typeToDisplayString( QVariant::DateTime ), QStringLiteral( "datetime" ), QVariant::DateTime, -1, -1, -1, -1 )
+                  << QgsVectorDataProvider::NativeType( QgsVariantUtils::typeToDisplayString( QMetaType::Type::QDate ), QStringLiteral( "date" ), QMetaType::Type::QDate, -1, -1, -1, -1 )
+                  << QgsVectorDataProvider::NativeType( QgsVariantUtils::typeToDisplayString( QMetaType::Type::QTime ), QStringLiteral( "time" ), QMetaType::Type::QTime, -1, -1, -1, -1 )
+                  << QgsVectorDataProvider::NativeType( QgsVariantUtils::typeToDisplayString( QMetaType::Type::QDateTime ), QStringLiteral( "datetime" ), QMetaType::Type::QDateTime, -1, -1, -1, -1 )
 
                   // integer types
-                  << QgsVectorDataProvider::NativeType( tr( "Whole Number (smallint - 16bit)" ), QStringLiteral( "int2" ), QVariant::Int, -1, -1, 0, 0 )
-                  << QgsVectorDataProvider::NativeType( tr( "Whole Number (integer - 32bit)" ), QStringLiteral( "int4" ), QVariant::Int, -1, -1, 0, 0 )
-                  << QgsVectorDataProvider::NativeType( tr( "Whole Number (integer - 64bit)" ), QStringLiteral( "int8" ), QVariant::LongLong, -1, -1, 0, 0 )
-                  << QgsVectorDataProvider::NativeType( tr( "Decimal Number (numeric)" ), QStringLiteral( "numeric" ), QVariant::Double, 1, 20, 0, 20 )
-                  << QgsVectorDataProvider::NativeType( tr( "Decimal Number (decimal)" ), QStringLiteral( "decimal" ), QVariant::Double, 1, 20, 0, 20 )
+                  << QgsVectorDataProvider::NativeType( tr( "Whole Number (smallint - 16bit)" ), QStringLiteral( "int2" ), QMetaType::Type::Int, -1, -1, 0, 0 )
+                  << QgsVectorDataProvider::NativeType( tr( "Whole Number (integer - 32bit)" ), QStringLiteral( "int4" ), QMetaType::Type::Int, -1, -1, 0, 0 )
+                  << QgsVectorDataProvider::NativeType( tr( "Whole Number (integer - 64bit)" ), QStringLiteral( "int8" ), QMetaType::Type::LongLong, -1, -1, 0, 0 )
+                  << QgsVectorDataProvider::NativeType( tr( "Decimal Number (numeric)" ), QStringLiteral( "numeric" ), QMetaType::Type::Double, 1, 20, 0, 20 )
+                  << QgsVectorDataProvider::NativeType( tr( "Decimal Number (decimal)" ), QStringLiteral( "decimal" ), QMetaType::Type::Double, 1, 20, 0, 20 )
 
                   // floating point
-                  << QgsVectorDataProvider::NativeType( tr( "Decimal Number (real)" ), QStringLiteral( "real" ), QVariant::Double, -1, -1, -1, -1 )
-                  << QgsVectorDataProvider::NativeType( tr( "Decimal Number (double)" ), QStringLiteral( "double precision" ), QVariant::Double, -1, -1, -1, -1 )
+                  << QgsVectorDataProvider::NativeType( tr( "Decimal Number (real)" ), QStringLiteral( "real" ), QMetaType::Type::Double, -1, -1, -1, -1 )
+                  << QgsVectorDataProvider::NativeType( tr( "Decimal Number (double)" ), QStringLiteral( "double precision" ), QMetaType::Type::Double, -1, -1, -1, -1 )
 
                   // string types
-                  << QgsVectorDataProvider::NativeType( tr( "Text, unlimited length (text)" ), QStringLiteral( "text" ), QVariant::String, -1, -1, -1, -1 )
+                  << QgsVectorDataProvider::NativeType( tr( "Text, unlimited length (text)" ), QStringLiteral( "text" ), QMetaType::Type::QString, -1, -1, -1, -1 )
 
                   // boolean
-                  << QgsVectorDataProvider::NativeType( QgsVariantUtils::typeToDisplayString( QVariant::Bool ), QStringLiteral( "boolean" ), QVariant::Bool )
+                  << QgsVectorDataProvider::NativeType( QgsVariantUtils::typeToDisplayString( QMetaType::Type::Bool ), QStringLiteral( "boolean" ), QMetaType::Type::Bool )
 
                   // blob
-                  << QgsVectorDataProvider::NativeType( QgsVariantUtils::typeToDisplayString( QVariant::ByteArray ), QStringLiteral( "binary" ), QVariant::ByteArray )
+                  << QgsVectorDataProvider::NativeType( QgsVariantUtils::typeToDisplayString( QMetaType::Type::QByteArray ), QStringLiteral( "binary" ), QMetaType::Type::QByteArray )
 
                   // list types
-                  << QgsVectorDataProvider::NativeType( QgsVariantUtils::typeToDisplayString( QVariant::StringList ), QStringLiteral( "stringlist" ), QVariant::StringList, 0, 0, 0, 0, QVariant::String )
-                  << QgsVectorDataProvider::NativeType( QgsVariantUtils::typeToDisplayString( QVariant::List, QVariant::Int ), QStringLiteral( "integerlist" ), QVariant::List, 0, 0, 0, 0, QVariant::Int )
-                  << QgsVectorDataProvider::NativeType( QgsVariantUtils::typeToDisplayString( QVariant::List, QVariant::Double ), QStringLiteral( "doublelist" ), QVariant::List, 0, 0, 0, 0, QVariant::Double )
-                  << QgsVectorDataProvider::NativeType( QgsVariantUtils::typeToDisplayString( QVariant::List, QVariant::LongLong ), QStringLiteral( "integer64list" ), QVariant::List, 0, 0, 0, 0, QVariant::LongLong )
+                  << QgsVectorDataProvider::NativeType( QgsVariantUtils::typeToDisplayString( QMetaType::Type::QStringList ), QStringLiteral( "stringlist" ), QMetaType::Type::QStringList, 0, 0, 0, 0, QMetaType::Type::QString )
+                  << QgsVectorDataProvider::NativeType( QgsVariantUtils::typeToDisplayString( QMetaType::Type::QVariantList, QMetaType::Type::Int ), QStringLiteral( "integerlist" ), QMetaType::Type::QVariantList, 0, 0, 0, 0, QMetaType::Type::Int )
+                  << QgsVectorDataProvider::NativeType( QgsVariantUtils::typeToDisplayString( QMetaType::Type::QVariantList, QMetaType::Type::Double ), QStringLiteral( "doublelist" ), QMetaType::Type::QVariantList, 0, 0, 0, 0, QMetaType::Type::Double )
+                  << QgsVectorDataProvider::NativeType( QgsVariantUtils::typeToDisplayString( QMetaType::Type::QVariantList, QMetaType::Type::LongLong ), QStringLiteral( "integer64list" ), QMetaType::Type::QVariantList, 0, 0, 0, 0, QMetaType::Type::LongLong )
 
                   // complex types
-                  << QgsVectorDataProvider::NativeType( QgsVariantUtils::typeToDisplayString( QVariant::Map ), QStringLiteral( "map" ), QVariant::Map, -1, -1, -1, -1 )
-                  << QgsVectorDataProvider::NativeType( tr( "Geometry" ), QStringLiteral( "geometry" ), QVariant::UserType )
+                  << QgsVectorDataProvider::NativeType( QgsVariantUtils::typeToDisplayString( QMetaType::Type::QVariantMap ), QStringLiteral( "map" ), QMetaType::Type::QVariantMap, -1, -1, -1, -1 )
+                  << QgsVectorDataProvider::NativeType( tr( "Geometry" ), QStringLiteral( "geometry" ), QMetaType::Type::User )
                 );
 
   if ( query.hasQueryItem( QStringLiteral( "field" ) ) )
@@ -139,8 +139,8 @@ QgsMemoryProvider::QgsMemoryProvider( const QString &uri, const ProviderOptions
       const QRegularExpressionMatch regularExpressionMatch = reFieldDef.match( name );
 
       // If no match -> use string as type
-      QVariant::Type type = QVariant::String;
-      QVariant::Type subType = QVariant::Invalid;
+      QMetaType::Type type = QMetaType::Type::QString;
+      QMetaType::Type subType = QMetaType::Type::UnknownType;
       QString typeName( QStringLiteral( "string" ) );
       int length = 255;
       int precision = 0;
@@ -170,23 +170,23 @@ QgsMemoryProvider::QgsMemoryProvider( const QString &uri, const ProviderOptions
         {
           if ( typeName == QLatin1String( "int" ) )
           {
-            type = QVariant::Int;
+            type = QMetaType::Type::Int;
             typeName = QStringLiteral( "integer" );
           }
           else if ( typeName == QLatin1String( "long" ) )
           {
-            type = QVariant::LongLong;
+            type = QMetaType::Type::LongLong;
             typeName = QStringLiteral( "int8" );
           }
           else if ( typeName == QLatin1String( "bool" ) )
           {
-            type = QVariant::Bool;
+            type = QMetaType::Type::Bool;
             typeName = QStringLiteral( "boolean" );
           }
           else
           {
             QgsLogger::warning( tr( "Unsupported typeName '%1'. Will be handled as string." ).arg( typeName ) );
-            type = QVariant::String;
+            type = QMetaType::Type::QString;
             typeName = QStringLiteral( "string" );
           }
         }
@@ -207,11 +207,11 @@ QgsMemoryProvider::QgsMemoryProvider( const QString &uri, const ProviderOptions
         // Array
         if ( !regularExpressionMatch.captured( 4 ).isEmpty() )
         {
-          if ( subType == QVariant::Invalid )
+          if ( subType == QMetaType::Type::UnknownType )
             subType = type;
 
-          if ( type != QVariant::List && type != QVariant::StringList )
-            type = type == QVariant::String ? QVariant::StringList : QVariant::List;
+          if ( type != QMetaType::Type::QVariantList && type != QMetaType::Type::QStringList )
+            type = type == QMetaType::Type::QString ? QMetaType::Type::QStringList : QMetaType::Type::QVariantList;
 
           const QLatin1String listSuffix( "list" );
           if ( !typeName.endsWith( listSuffix ) )
@@ -287,23 +287,23 @@ QString QgsMemoryProvider::dataSourceUri( bool expandAuthConfig ) const
 
     QString typeName = field.typeName();
     bool isList = false;
-    if ( field.type() == QVariant::List || field.type() == QVariant::StringList )
+    if ( field.type() == QMetaType::Type::QVariantList || field.type() == QMetaType::Type::QStringList )
     {
       switch ( field.subType() )
       {
-        case QVariant::Int:
+        case QMetaType::Type::Int:
           typeName = QStringLiteral( "integer" );
           break;
 
-        case QVariant::LongLong:
+        case QMetaType::Type::LongLong:
           typeName = QStringLiteral( "long" );
           break;
 
-        case QVariant::Double:
+        case QMetaType::Type::Double:
           typeName = QStringLiteral( "double" );
           break;
 
-        case QVariant::String:
+        case QMetaType::Type::QString:
           typeName = QStringLiteral( "string" );
           break;
 
@@ -433,21 +433,22 @@ bool QgsMemoryProvider::addFeatures( QgsFeatureList &flist, Flags flags )
   {
     it->setId( mNextFeatureId );
     it->setValid( true );
-    if ( it->attributes().count() < fieldCount )
+    const int attributeCount = it->attributeCount();
+    if ( attributeCount < fieldCount )
     {
       // ensure features have the correct number of attributes by padding
       // them with null attributes for missing values
       QgsAttributes attributes = it->attributes();
-      for ( int i = it->attributes().count(); i < mFields.count(); ++i )
+      for ( int i = attributeCount; i < mFields.count(); ++i )
       {
-        attributes.append( QVariant( mFields.at( i ).type() ) );
+        attributes.append( QgsVariantUtils::createNullVariant( mFields.at( i ).type() ) );
       }
       it->setAttributes( attributes );
     }
-    else if ( it->attributes().count() > fieldCount )
+    else if ( attributeCount > fieldCount )
     {
       // too many attributes
-      pushError( tr( "Feature has too many attributes (expecting %1, received %2)" ).arg( fieldCount ).arg( it->attributes().count() ) );
+      pushError( tr( "Feature has too many attributes (expecting %1, received %2)" ).arg( fieldCount ).arg( attributeCount ) );
       QgsAttributes attributes = it->attributes();
       attributes.resize( mFields.count() );
       it->setAttributes( attributes );
@@ -485,7 +486,7 @@ bool QgsMemoryProvider::addFeatures( QgsFeatureList &flist, Flags flags )
         conversionError = true;
         continue;
       }
-      else if ( attrValue.type() != originalValue.type() )
+      else if ( attrValue.userType() != originalValue.userType() )
       {
         // convertCompatible has resulted in a data type conversion
         it->setAttribute( i, attrValue );
@@ -569,7 +570,7 @@ bool QgsMemoryProvider::addAttributes( const QList<QgsField> &attributes )
 
     // Make sure added attributes typeName correspond to a native type name
     bool isNativeTypeName = false;
-    NativeType nativeTypeCandidate( QString(), QString(), QVariant::Invalid );
+    NativeType nativeTypeCandidate( QString(), QString(), QMetaType::Type::UnknownType );
     const QList<QgsVectorDataProvider::NativeType> nativeTypesList( nativeTypes() );
     for ( const NativeType &nativeType : nativeTypesList )
     {
@@ -580,12 +581,12 @@ bool QgsMemoryProvider::addAttributes( const QList<QgsField> &attributes )
       }
 
       if ( nativeType.mType == field.type()
-           && nativeTypeCandidate.mType == QVariant::Invalid )
+           && nativeTypeCandidate.mType == QMetaType::Type::UnknownType )
         nativeTypeCandidate = nativeType;
     }
     if ( !isNativeTypeName )
     {
-      if ( nativeTypeCandidate.mType == QVariant::Invalid )
+      if ( nativeTypeCandidate.mType == QMetaType::Type::UnknownType )
       {
         QgsLogger::warning( "Field type not supported: " + field.typeName() );
         continue;
