@@ -44,12 +44,18 @@ QgsField::QgsField( QString nam, QString typ, int len, int prec, bool num,
   // names how they are now.
 }
 #endif
-QgsField::QgsField( const QString &name, QVariant::Type type,
-                    const QString &typeName, int len, int prec, const QString &comment, QVariant::Type subType )
+QgsField::QgsField( const QString &name, QMetaType::Type type,
+                    const QString &typeName, int len, int prec, const QString &comment, QMetaType::Type subType )
 {
   d = new QgsFieldPrivate( name, type, subType, typeName, len, prec, comment );
 }
 
+QgsField::QgsField( const QString &name, QVariant::Type type,
+                    const QString &typeName, int len, int prec, const QString &comment, QVariant::Type subType )
+  : QgsField( name, QgsVariantUtils::variantTypeToMetaType( type ), typeName, len, prec, comment, QgsVariantUtils::variantTypeToMetaType( subType ) )
+{
+}
+
 QgsField::QgsField( const QgsField &other ) //NOLINT
   : d( other.d )
 {
@@ -105,6 +111,10 @@ QString QgsField::displayNameWithAlias() const
 QString QgsField::displayType( const bool showConstraints ) const
 {
   QString typeStr = typeName();
+  if ( typeStr.isEmpty() )
+  {
+    typeStr = QgsVariantUtils::typeToDisplayString( type(), subType() );
+  }
 
   if ( length() > 0 && precision() > 0 )
     typeStr += QStringLiteral( "(%1, %2)" ).arg( length() ).arg( precision() );
@@ -127,7 +137,7 @@ QString QgsField::displayType( const bool showConstraints ) const
 
 QString QgsField::friendlyTypeString() const
 {
-  if ( d->type == QVariant::UserType )
+  if ( d->type == QMetaType::Type::User )
   {
     if ( d->typeName.compare( QLatin1String( "geometry" ), Qt::CaseInsensitive ) == 0 )
     {
@@ -137,12 +147,12 @@ QString QgsField::friendlyTypeString() const
   return QgsVariantUtils::typeToDisplayString( d->type, d->subType );
 }
 
-QVariant::Type QgsField::type() const
+QMetaType::Type QgsField::type() const
 {
   return d->type;
 }
 
-QVariant::Type QgsField::subType() const
+QMetaType::Type QgsField::subType() const
 {
   return d->subType;
 }
@@ -199,12 +209,12 @@ void QgsField::setMetadata( int property, const QVariant &value )
 
 bool QgsField::isNumeric() const
 {
-  return d->type == QVariant::Double || d->type == QVariant::Int || d->type == QVariant::UInt || d->type == QVariant::LongLong || d->type == QVariant::ULongLong;
+  return d->type == QMetaType::Type::Double || d->type == QMetaType::Type::Int || d->type == QMetaType::Type::UInt || d->type == QMetaType::Type::LongLong || d->type == QMetaType::Type::ULongLong;
 }
 
 bool QgsField::isDateOrTime() const
 {
-  return d->type == QVariant::Date || d->type == QVariant::Time || d->type == QVariant::DateTime;
+  return d->type == QMetaType::Type::QDate || d->type == QMetaType::Type::QTime || d->type == QMetaType::Type::QDateTime;
 }
 
 /***************************************************************************
@@ -218,16 +228,26 @@ void QgsField::setName( const QString &name )
   d->name = name;
 }
 
-void QgsField::setType( QVariant::Type type )
+void QgsField::setType( QMetaType::Type type )
 {
   d->type = type;
 }
 
-void QgsField::setSubType( QVariant::Type subType )
+void QgsField::setType( QVariant::Type type )
+{
+  setType( QgsVariantUtils::variantTypeToMetaType( type ) );
+}
+
+void QgsField::setSubType( QMetaType::Type subType )
 {
   d->subType = subType;
 }
 
+void QgsField::setSubType( QVariant::Type subType )
+{
+  setSubType( QgsVariantUtils::variantTypeToMetaType( subType ) );
+}
+
 void QgsField::setTypeName( const QString &typeName )
 {
   d->typeName = typeName;
@@ -318,7 +338,7 @@ QString QgsField::displayString( const QVariant &v ) const
   }
 
   // Special treatment for numeric types if group separator is set or decimalPoint is not a dot
-  if ( d->type == QVariant::Double )
+  if ( d->type == QMetaType::Type::Double )
   {
     // if value doesn't contain a double (a default value expression for instance),
     // apply no transformation
@@ -406,11 +426,11 @@ QString QgsField::displayString( const QVariant &v ) const
     const QJsonDocument doc = QJsonDocument::fromVariant( v );
     return QString::fromUtf8( doc.toJson().constData() );
   }
-  else if ( d->type == QVariant::ByteArray )
+  else if ( d->type == QMetaType::Type::QByteArray )
   {
     return QObject::tr( "BLOB" );
   }
-  else if ( d->type == QVariant::StringList || d->type == QVariant::List )
+  else if ( d->type == QMetaType::Type::QStringList || d->type == QMetaType::Type::QVariantList )
   {
     QString result;
     const QVariantList list = v.toList();
@@ -461,9 +481,9 @@ bool QgsField::convertCompatible( QVariant &v, QString *errorMessage ) const
     return true;
   }
 
-  if ( d->type == QVariant::Int && v.toInt() != v.toLongLong() )
+  if ( d->type == QMetaType::Type::Int && v.toInt() != v.toLongLong() )
   {
-    v = QVariant( d->type );
+    v = QgsVariantUtils::createNullVariant( d->type );
     if ( errorMessage )
       *errorMessage = QObject::tr( "Value \"%1\" is too large for integer field" ).arg( original.toLongLong() );
     return false;
@@ -471,7 +491,7 @@ bool QgsField::convertCompatible( QVariant &v, QString *errorMessage ) const
 
   // Give it a chance to convert to double since for not '.' locales
   // we accept both comma and dot as decimal point
-  if ( d->type == QVariant::Double && v.type() == QVariant::String )
+  if ( d->type == QMetaType::Type::Double && v.userType() == QMetaType::Type::QString )
   {
     QVariant tmp( v );
     if ( !tmp.convert( d->type ) )
@@ -498,7 +518,7 @@ bool QgsField::convertCompatible( QVariant &v, QString *errorMessage ) const
   }
 
   // For string representation of an int we also might have thousand separator
-  if ( d->type == QVariant::Int && v.type() == QVariant::String )
+  if ( d->type == QMetaType::Type::Int && v.userType() == QMetaType::Type::QString )
   {
     QVariant tmp( v );
     if ( !tmp.convert( d->type ) )
@@ -515,7 +535,7 @@ bool QgsField::convertCompatible( QVariant &v, QString *errorMessage ) const
   }
 
   // For string representation of a long we also might have thousand separator
-  if ( d->type == QVariant::LongLong && v.type() == QVariant::String )
+  if ( d->type == QMetaType::Type::LongLong && v.userType() == QMetaType::Type::QString )
   {
     QVariant tmp( v );
     if ( !tmp.convert( d->type ) )
@@ -533,14 +553,14 @@ bool QgsField::convertCompatible( QVariant &v, QString *errorMessage ) const
 
   //String representations of doubles in QVariant will return false to convert( QVariant::Int )
   //work around this by first converting to double, and then checking whether the double is convertible to int
-  if ( d->type == QVariant::Int && v.canConvert( QVariant::Double ) )
+  if ( d->type == QMetaType::Type::Int && v.canConvert( QMetaType::Type::Double ) )
   {
     bool ok = false;
     const double dbl = v.toDouble( &ok );
     if ( !ok )
     {
       //couldn't convert to number
-      v = QVariant( d->type );
+      v = QgsVariantUtils::createNullVariant( d->type );
 
       if ( errorMessage )
         *errorMessage = QObject::tr( "Value \"%1\" is not a number" ).arg( original.toString() );
@@ -552,7 +572,7 @@ bool QgsField::convertCompatible( QVariant &v, QString *errorMessage ) const
     if ( round  > std::numeric_limits<int>::max() || round < -std::numeric_limits<int>::max() )
     {
       //double too large to fit in int
-      v = QVariant( d->type );
+      v = QgsVariantUtils::createNullVariant( d->type );
 
       if ( errorMessage )
         *errorMessage = QObject::tr( "Value \"%1\" is too large for integer field" ).arg( original.toDouble() );
@@ -565,7 +585,7 @@ bool QgsField::convertCompatible( QVariant &v, QString *errorMessage ) const
 
   //String representations of doubles in QVariant will return false to convert( QVariant::LongLong )
   //work around this by first converting to double, and then checking whether the double is convertible to longlong
-  if ( d->type == QVariant::LongLong && v.canConvert( QVariant::Double ) )
+  if ( d->type == QMetaType::Type::LongLong && v.canConvert( QMetaType::Type::Double ) )
   {
     //firstly test the conversion to longlong because conversion to double will rounded the value
     QVariant tmp( v );
@@ -576,7 +596,7 @@ bool QgsField::convertCompatible( QVariant &v, QString *errorMessage ) const
       if ( !ok )
       {
         //couldn't convert to number
-        v = QVariant( d->type );
+        v = QgsVariantUtils::createNullVariant( d->type );
 
         if ( errorMessage )
           *errorMessage = QObject::tr( "Value \"%1\" is not a number" ).arg( original.toString() );
@@ -588,7 +608,7 @@ bool QgsField::convertCompatible( QVariant &v, QString *errorMessage ) const
       if ( round  > static_cast<double>( std::numeric_limits<long long>::max() ) || round < static_cast<double>( -std::numeric_limits<long long>::max() ) )
       {
         //double too large to fit in longlong
-        v = QVariant( d->type );
+        v = QgsVariantUtils::createNullVariant( d->type );
 
         if ( errorMessage )
           *errorMessage = QObject::tr( "Value \"%1\" is too large for long long field" ).arg( original.toDouble() );
@@ -602,7 +622,7 @@ bool QgsField::convertCompatible( QVariant &v, QString *errorMessage ) const
 
   if ( d->typeName.compare( QLatin1String( "json" ), Qt::CaseInsensitive ) == 0 || d->typeName.compare( QLatin1String( "jsonb" ), Qt::CaseInsensitive ) == 0 )
   {
-    if ( d->type == QVariant::String )
+    if ( d->type == QMetaType::Type::QString )
     {
       const QJsonDocument doc = QJsonDocument::fromVariant( v );
       if ( !doc.isNull() )
@@ -610,30 +630,30 @@ bool QgsField::convertCompatible( QVariant &v, QString *errorMessage ) const
         v = QString::fromUtf8( doc.toJson( QJsonDocument::Compact ).constData() );
         return true;
       }
-      v = QVariant( d->type );
+      v = QgsVariantUtils::createNullVariant( d->type );
       return false;
     }
-    else if ( d->type == QVariant::Map )
+    else if ( d->type == QMetaType::Type::QVariantMap )
     {
-      if ( v.type() == QVariant::StringList || v.type() == QVariant::List || v.type() == QVariant::Map )
+      if ( v.userType() == QMetaType::Type::QStringList || v.userType() == QMetaType::Type::QVariantList || v.userType() == QMetaType::Type::QVariantMap )
       {
         return true;
       }
-      v = QVariant( d->type );
+      v = QgsVariantUtils::createNullVariant( d->type );
       return false;
     }
   }
 
-  if ( ( d->type == QVariant::StringList || ( d->type == QVariant::List && d->subType == QVariant::String ) )
-       && ( v.type() == QVariant::String ) )
+  if ( ( d->type == QMetaType::Type::QStringList || ( d->type == QMetaType::Type::QVariantList && d->subType == QMetaType::Type::QString ) )
+       && ( v.userType() == QMetaType::Type::QString ) )
   {
     v = QStringList( { v.toString() } );
     return true;
   }
 
-  if ( ( d->type == QVariant::StringList || d->type == QVariant::List ) && !( v.type() == QVariant::StringList || v.type() == QVariant::List ) )
+  if ( ( d->type == QMetaType::Type::QStringList || d->type == QMetaType::Type::QVariantList ) && !( v.userType() == QMetaType::Type::QStringList || v.userType() == QMetaType::Type::QVariantList ) )
   {
-    v = QVariant( d->type );
+    v = QgsVariantUtils::createNullVariant( d->type );
 
     if ( errorMessage )
       *errorMessage = QObject::tr( "Could not convert value \"%1\" to target list type" ).arg( original.toString() );
@@ -642,12 +662,12 @@ bool QgsField::convertCompatible( QVariant &v, QString *errorMessage ) const
   }
 
   // Handle referenced geometries (e.g. from additional geometry fields)
-  if ( d->type == QVariant::String && v.userType() == QMetaType::type( "QgsReferencedGeometry" ) )
+  if ( d->type == QMetaType::Type::QString && v.userType() == QMetaType::type( "QgsReferencedGeometry" ) )
   {
     const QgsReferencedGeometry geom { v.value<QgsReferencedGeometry>( ) };
     if ( geom.isNull() )
     {
-      v = QVariant( d->type );
+      v = QgsVariantUtils::createNullVariant( d->type );
     }
     else
     {
@@ -655,13 +675,13 @@ bool QgsField::convertCompatible( QVariant &v, QString *errorMessage ) const
     }
     return true;
   }
-  else if ( d->type == QVariant::UserType && d->typeName.compare( QLatin1String( "geometry" ), Qt::CaseInsensitive ) == 0 )
+  else if ( d->type == QMetaType::Type::User && d->typeName.compare( QLatin1String( "geometry" ), Qt::CaseInsensitive ) == 0 )
   {
     if ( v.userType() == QMetaType::type( "QgsReferencedGeometry" ) || v.userType() == QMetaType::type( "QgsGeometry" ) )
     {
       return true;
     }
-    else if ( v.type() == QVariant::String )
+    else if ( v.userType() == QMetaType::Type::QString )
     {
       const QgsGeometry geom = QgsGeometry::fromWkt( v.toString() );
       if ( !geom.isNull() )
@@ -674,7 +694,7 @@ bool QgsField::convertCompatible( QVariant &v, QString *errorMessage ) const
   }
   else if ( !v.convert( d->type ) )
   {
-    v = QVariant( d->type );
+    v = QgsVariantUtils::createNullVariant( d->type );
 
     if ( errorMessage )
       *errorMessage = QObject::tr( "Could not convert value \"%1\" to target type \"%2\"" )
@@ -684,7 +704,7 @@ bool QgsField::convertCompatible( QVariant &v, QString *errorMessage ) const
     return false;
   }
 
-  if ( d->type == QVariant::Double && d->precision > 0 )
+  if ( d->type == QMetaType::Type::Double && d->precision > 0 )
   {
     const double s = std::pow( 10, d->precision );
     const double d = v.toDouble() * s;
@@ -692,7 +712,7 @@ bool QgsField::convertCompatible( QVariant &v, QString *errorMessage ) const
     return true;
   }
 
-  if ( d->type == QVariant::String && d->length > 0 && v.toString().length() > d->length )
+  if ( d->type == QMetaType::Type::QString && d->length > 0 && v.toString().length() > d->length )
   {
     const int length = v.toString().length();
     v = v.toString().left( d->length );
@@ -706,6 +726,11 @@ bool QgsField::convertCompatible( QVariant &v, QString *errorMessage ) const
   return true;
 }
 
+QgsField::operator QVariant() const
+{
+  return QVariant::fromValue( *this );
+}
+
 void QgsField::setEditorWidgetSetup( const QgsEditorWidgetSetup &v )
 {
   d->editorWidgetSetup = v;
@@ -736,6 +761,16 @@ void QgsField::setSplitPolicy( Qgis::FieldDomainSplitPolicy policy )
   d->splitPolicy = policy;
 }
 
+Qgis::FieldDuplicatePolicy QgsField::duplicatePolicy() const
+{
+  return d->duplicatePolicy;
+}
+
+void QgsField::setDuplicatePolicy( Qgis::FieldDuplicatePolicy policy )
+{
+  d->duplicatePolicy = policy;
+}
+
 /***************************************************************************
  * This class is considered CRITICAL and any change MUST be accompanied with
  * full unit tests in testqgsfield.cpp.
@@ -764,6 +799,7 @@ QDataStream &operator<<( QDataStream &out, const QgsField &field )
   out << field.constraints().constraintDescription();
   out << static_cast< quint32 >( field.subType() );
   out << static_cast< int >( field.splitPolicy() );
+  out << static_cast< int >( field.duplicatePolicy() );
   out << field.metadata();
   return out;
 }
@@ -782,6 +818,7 @@ QDataStream &operator>>( QDataStream &in, QgsField &field )
   quint32 strengthUnique;
   quint32 strengthExpression;
   int splitPolicy;
+  int duplicatePolicy;
 
   bool applyOnUpdate;
 
@@ -796,9 +833,9 @@ QDataStream &operator>>( QDataStream &in, QgsField &field )
 
   in >> name >> type >> typeName >> length >> precision >> comment >> alias
      >> defaultValueExpression >> applyOnUpdate >> constraints >> originNotNull >> originUnique >> originExpression >> strengthNotNull >> strengthUnique >> strengthExpression >>
-     constraintExpression >> constraintDescription >> subType >> splitPolicy >> metadata;
+     constraintExpression >> constraintDescription >> subType >> splitPolicy >> duplicatePolicy >> metadata;
   field.setName( name );
-  field.setType( static_cast< QVariant::Type >( type ) );
+  field.setType( static_cast< QMetaType::Type >( type ) );
   field.setTypeName( typeName );
   field.setLength( static_cast< int >( length ) );
   field.setPrecision( static_cast< int >( precision ) );
@@ -806,6 +843,7 @@ QDataStream &operator>>( QDataStream &in, QgsField &field )
   field.setAlias( alias );
   field.setDefaultValueDefinition( QgsDefaultValue( defaultValueExpression, applyOnUpdate ) );
   field.setSplitPolicy( static_cast< Qgis::FieldDomainSplitPolicy >( splitPolicy ) );
+  field.setDuplicatePolicy( static_cast< Qgis::FieldDuplicatePolicy >( duplicatePolicy ) );
   QgsFieldConstraints fieldConstraints;
   if ( constraints & QgsFieldConstraints::ConstraintNotNull )
   {
@@ -830,7 +868,7 @@ QDataStream &operator>>( QDataStream &in, QgsField &field )
     fieldConstraints.removeConstraint( QgsFieldConstraints::ConstraintExpression );
   fieldConstraints.setConstraintExpression( constraintExpression, constraintDescription );
   field.setConstraints( fieldConstraints );
-  field.setSubType( static_cast< QVariant::Type >( subType ) );
+  field.setSubType( static_cast< QMetaType::Type >( subType ) );
   field.setMetadata( metadata );
   return in;
 }
