@@ -49,6 +49,7 @@
 #include "qgsrastertransparency.h"
 #include "qgssinglebandgrayrendererwidget.h"
 #include "qgssinglebandpseudocolorrendererwidget.h"
+#include "qgsrastersinglecolorrendererwidget.h"
 #include "qgshuesaturationfilter.h"
 #include "qgshillshaderendererwidget.h"
 #include "qgssettings.h"
@@ -308,7 +309,9 @@ QgsRasterLayerProperties::QgsRasterLayerProperties( QgsMapLayer *lyr, QgsMapCanv
   QgsRasterDataProvider *provider = mRasterLayer->dataProvider();
 
   // Only do pyramids if dealing directly with GDAL.
-  if ( provider && provider->capabilities() & QgsRasterDataProvider::BuildPyramids )
+  if ( provider &&
+       ( provider->capabilities() & Qgis::RasterInterfaceCapability::BuildPyramids
+         || provider->providerCapabilities() & Qgis::RasterProviderCapability::BuildPyramids ) )
   {
     // initialize resampling methods
     cboResamplingMethod->clear();
@@ -356,7 +359,7 @@ QgsRasterLayerProperties::QgsRasterLayerProperties( QgsMapLayer *lyr, QgsMapCanv
   // We can calculate histogram for all data sources but estimated only if
   // size is unknown - could also be enabled if well supported (estimated histogram
   // and let user know that it is estimated)
-  if ( !provider || !( provider->capabilities() & QgsRasterDataProvider::Size ) )
+  if ( !provider || !( provider->capabilities() & Qgis::RasterInterfaceCapability::Size ) )
   {
     // disable Histogram tab completely
     mOptsPage_Histogram->setEnabled( false );
@@ -462,6 +465,7 @@ QgsRasterLayerProperties::QgsRasterLayerProperties( QgsMapLayer *lyr, QgsMapCanv
   QgsApplication::rasterRendererRegistry()->insertWidgetFunction( QStringLiteral( "singlebandgray" ), QgsSingleBandGrayRendererWidget::create );
   QgsApplication::rasterRendererRegistry()->insertWidgetFunction( QStringLiteral( "hillshade" ), QgsHillshadeRendererWidget::create );
   QgsApplication::rasterRendererRegistry()->insertWidgetFunction( QStringLiteral( "contour" ), QgsRasterContourRendererWidget::create );
+  QgsApplication::rasterRendererRegistry()->insertWidgetFunction( QStringLiteral( "singlecolor" ), QgsRasterSingleColorRendererWidget::create );
 
   //fill available renderers into combo box
   QgsRasterRendererRegistryEntry entry;
@@ -771,7 +775,8 @@ void QgsRasterLayerProperties::sync()
   }
 
   // TODO: Wouldn't it be better to just removeWidget() the tabs than delete them? [LS]
-  if ( !( provider->capabilities() & QgsRasterDataProvider::BuildPyramids ) )
+  if ( !( provider->capabilities() & Qgis::RasterInterfaceCapability::BuildPyramids
+          || provider->providerCapabilities() & Qgis::RasterProviderCapability::BuildPyramids ) )
   {
     if ( mOptsPage_Pyramids )
     {
@@ -780,7 +785,7 @@ void QgsRasterLayerProperties::sync()
     }
   }
 
-  if ( !( provider->capabilities() & QgsRasterDataProvider::Size ) )
+  if ( !( provider->capabilities() & Qgis::RasterInterfaceCapability::Size ) )
   {
     if ( mOptsPage_Histogram )
     {
@@ -842,25 +847,25 @@ void QgsRasterLayerProperties::sync()
   updateInformationContent();
 
   // WMS Name as layer short name
-  mLayerShortNameLineEdit->setText( mRasterLayer->shortName() );
+  mLayerShortNameLineEdit->setText( mRasterLayer->serverProperties()->shortName() );
   // WMS Name validator
   QValidator *shortNameValidator = new QRegularExpressionValidator( QgsApplication::shortNameRegularExpression(), this );
   mLayerShortNameLineEdit->setValidator( shortNameValidator );
 
   //layer title and abstract
-  mLayerTitleLineEdit->setText( mRasterLayer->title() );
-  mLayerAbstractTextEdit->setPlainText( mRasterLayer->abstract() );
-  mLayerKeywordListLineEdit->setText( mRasterLayer->keywordList() );
-  mLayerDataUrlLineEdit->setText( mRasterLayer->dataUrl() );
+  mLayerTitleLineEdit->setText( mRasterLayer->serverProperties()->title() );
+  mLayerAbstractTextEdit->setPlainText( mRasterLayer->serverProperties()->abstract() );
+  mLayerKeywordListLineEdit->setText( mRasterLayer->serverProperties()->keywordList() );
+  mLayerDataUrlLineEdit->setText( mRasterLayer->serverProperties()->dataUrl() );
   mLayerDataUrlFormatComboBox->setCurrentIndex(
     mLayerDataUrlFormatComboBox->findText(
-      mRasterLayer->dataUrlFormat()
+      mRasterLayer->serverProperties()->dataUrlFormat()
     )
   );
 
   //layer attribution
-  mLayerAttributionLineEdit->setText( mRasterLayer->attribution() );
-  mLayerAttributionUrlLineEdit->setText( mRasterLayer->attributionUrl() );
+  mLayerAttributionLineEdit->setText( mRasterLayer->serverProperties()->attribution() );
+  mLayerAttributionUrlLineEdit->setText( mRasterLayer->serverProperties()->attributionUrl() );
 
   // layer metadata url
   const QList<QgsMapLayerServerProperties::MetadataUrl> &metaUrls = mRasterLayer->serverProperties()->metadataUrls();
@@ -995,29 +1000,31 @@ void QgsRasterLayerProperties::apply()
     QgsRasterTransparency *rasterTransparency = new QgsRasterTransparency();
     if ( mRasterTransparencyWidget->tableTransparency->columnCount() == 4 )
     {
-      QgsRasterTransparency::TransparentThreeValuePixel myTransparentPixel;
-      QList<QgsRasterTransparency::TransparentThreeValuePixel> myTransparentThreeValuePixelList;
+      QVector<QgsRasterTransparency::TransparentThreeValuePixel> myTransparentThreeValuePixelList;
       for ( int myListRunner = 0; myListRunner < mRasterTransparencyWidget->tableTransparency->rowCount(); myListRunner++ )
       {
-        myTransparentPixel.red = transparencyCellValue( myListRunner, 0 );
-        myTransparentPixel.green = transparencyCellValue( myListRunner, 1 );
-        myTransparentPixel.blue = transparencyCellValue( myListRunner, 2 );
-        myTransparentPixel.percentTransparent = transparencyCellValue( myListRunner, 3 );
-        myTransparentThreeValuePixelList.append( myTransparentPixel );
+        const double red = transparencyCellValue( myListRunner, 0 );
+        const double green = transparencyCellValue( myListRunner, 1 );
+        const double blue = transparencyCellValue( myListRunner, 2 );
+        const double opacity = 1.0 - transparencyCellValue( myListRunner, 3 ) / 100.0;
+        myTransparentThreeValuePixelList.append(
+          QgsRasterTransparency::TransparentThreeValuePixel( red, green, blue, opacity )
+        );
       }
       rasterTransparency->setTransparentThreeValuePixelList( myTransparentThreeValuePixelList );
     }
     else if ( mRasterTransparencyWidget->tableTransparency->columnCount() == 3 )
     {
-      QgsRasterTransparency::TransparentSingleValuePixel myTransparentPixel;
-      QList<QgsRasterTransparency::TransparentSingleValuePixel> myTransparentSingleValuePixelList;
+      QVector<QgsRasterTransparency::TransparentSingleValuePixel> myTransparentSingleValuePixelList;
       for ( int myListRunner = 0; myListRunner < mRasterTransparencyWidget->tableTransparency->rowCount(); myListRunner++ )
       {
-        myTransparentPixel.min = transparencyCellValue( myListRunner, 0 );
-        myTransparentPixel.max = transparencyCellValue( myListRunner, 1 );
-        myTransparentPixel.percentTransparent = transparencyCellValue( myListRunner, 2 );
+        const double min = transparencyCellValue( myListRunner, 0 );
+        const double max = transparencyCellValue( myListRunner, 1 );
+        const double opacity = 1.0 - transparencyCellValue( myListRunner, 2 ) / 100.0;
 
-        myTransparentSingleValuePixelList.append( myTransparentPixel );
+        myTransparentSingleValuePixelList.append(
+          QgsRasterTransparency::TransparentSingleValuePixel( min, max, opacity )
+        );
       }
       rasterTransparency->setTransparentSingleValuePixelList( myTransparentSingleValuePixelList );
     }
@@ -1071,38 +1078,38 @@ void QgsRasterLayerProperties::apply()
 
   mRasterLayer->setCrs( mCrsSelector->crs() );
 
-  if ( mRasterLayer->shortName() != mLayerShortNameLineEdit->text() )
+  if ( mRasterLayer->serverProperties()->shortName() != mLayerShortNameLineEdit->text() )
     mMetadataFilled = false;
-  mRasterLayer->setShortName( mLayerShortNameLineEdit->text() );
+  mRasterLayer->serverProperties()->setShortName( mLayerShortNameLineEdit->text() );
 
-  if ( mRasterLayer->title() != mLayerTitleLineEdit->text() )
+  if ( mRasterLayer->serverProperties()->title() != mLayerTitleLineEdit->text() )
     mMetadataFilled = false;
-  mRasterLayer->setTitle( mLayerTitleLineEdit->text() );
+  mRasterLayer->serverProperties()->setTitle( mLayerTitleLineEdit->text() );
 
-  if ( mRasterLayer->abstract() != mLayerAbstractTextEdit->toPlainText() )
+  if ( mRasterLayer->serverProperties()->abstract() != mLayerAbstractTextEdit->toPlainText() )
     mMetadataFilled = false;
-  mRasterLayer->setAbstract( mLayerAbstractTextEdit->toPlainText() );
+  mRasterLayer->serverProperties()->setAbstract( mLayerAbstractTextEdit->toPlainText() );
 
-  if ( mRasterLayer->keywordList() != mLayerKeywordListLineEdit->text() )
+  if ( mRasterLayer->serverProperties()->keywordList() != mLayerKeywordListLineEdit->text() )
     mMetadataFilled = false;
-  mRasterLayer->setKeywordList( mLayerKeywordListLineEdit->text() );
+  mRasterLayer->serverProperties()->setKeywordList( mLayerKeywordListLineEdit->text() );
 
-  if ( mRasterLayer->dataUrl() != mLayerDataUrlLineEdit->text() )
+  if ( mRasterLayer->serverProperties()->dataUrl() != mLayerDataUrlLineEdit->text() )
     mMetadataFilled = false;
-  mRasterLayer->setDataUrl( mLayerDataUrlLineEdit->text() );
+  mRasterLayer->serverProperties()->setDataUrl( mLayerDataUrlLineEdit->text() );
 
-  if ( mRasterLayer->dataUrlFormat() != mLayerDataUrlFormatComboBox->currentText() )
+  if ( mRasterLayer->serverProperties()->dataUrlFormat() != mLayerDataUrlFormatComboBox->currentText() )
     mMetadataFilled = false;
-  mRasterLayer->setDataUrlFormat( mLayerDataUrlFormatComboBox->currentText() );
+  mRasterLayer->serverProperties()->setDataUrlFormat( mLayerDataUrlFormatComboBox->currentText() );
 
   //layer attribution
-  if ( mRasterLayer->attribution() != mLayerAttributionLineEdit->text() )
+  if ( mRasterLayer->serverProperties()->attribution() != mLayerAttributionLineEdit->text() )
     mMetadataFilled = false;
-  mRasterLayer->setAttribution( mLayerAttributionLineEdit->text() );
+  mRasterLayer->serverProperties()->setAttribution( mLayerAttributionLineEdit->text() );
 
-  if ( mRasterLayer->attributionUrl() != mLayerAttributionUrlLineEdit->text() )
+  if ( mRasterLayer->serverProperties()->attributionUrl() != mLayerAttributionUrlLineEdit->text() )
     mMetadataFilled = false;
-  mRasterLayer->setAttributionUrl( mLayerAttributionUrlLineEdit->text() );
+  mRasterLayer->serverProperties()->setAttributionUrl( mLayerAttributionUrlLineEdit->text() );
 
   // Metadata URL
   QList<QgsMapLayerServerProperties::MetadataUrl> metaUrls;
